import { StructuredError } from '@agentuity/core';
export const DbResponseError = StructuredError('DbResponseError')();
export const DbInvalidArgumentError = StructuredError('DbInvalidArgumentError')();
//# sourceMappingURL=util.js.map